# pyquac
Useful tools for quantum computing experiments in **Jupyter notebook**, provided for BMSTU FMN  
# Description  
package consists of two main modules:  
- `fmn_plottools`: Plot data with plotly package  
- `fmn_datatools`: **(IN PROGRESS)**. Tools to work with data. Send signal to the machine, pull request, generate pandas DataFrame from it, get approximation result etc.  

There is also `datatools` module, but it just an simplier analog of `fmn_plottools` that soon would be removed.  
# Installation  
## Normal installation  
```
pip install pyquac
```
## Development installation  
```
git clone https://github.com/ikaryss/pyquac.git
```